"""
Author: Maximilian Wolf (max@w0lf.me)
License: GPLv3
"""


__version__ = '2.1.1'

from .crawlio import Crawler, Selector
